'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var language = require('@codemirror/language');
var autocomplete = require('@codemirror/autocomplete');
var lint = require('@codemirror/lint');
var lr = require('@lezer/lr');
var highlight = require('@lezer/highlight');

var collection = {
	type: "HEAD",
	shortDescription: "The constraint specifies which entity collection will be searched for results.",
	userDocsLink: "https://evitadb.io/documentation/query/basics#header"
};
var filterGroupBy = {
	type: "FILTER",
	shortDescription: "The container encapsulating filter constraint limiting the facet groups returned in facet summary.",
	userDocsLink: "https://evitadb.io/documentation/query/basics#filter-by"
};
var attributeGreaterThanEquals = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute is greater than or equals to the passed value.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-greater-than-equals"
};
var filterBy = {
	type: "FILTER",
	shortDescription: "The container encapsulating inner filter constraint into one main constraint that is required by the query.",
	userDocsLink: "https://evitadb.io/documentation/query/basics#filter-by"
};
var priceBetween = {
	type: "FILTER",
	shortDescription: "The constraint checks if entity has price for sale within the passed range of prices (both ends are inclusive).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/price#price-between"
};
var entityHaving = {
	type: "FILTER",
	shortDescription: "The container allowing to filter entities by having references to entities managed by evitaDB that  + match inner filtering constraints. This container resembles the SQL inner join clauses where the `entityHaving` + contains the filtering condition on particular join.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/references#entity-having"
};
var priceInCurrency = {
	type: "FILTER",
	shortDescription: "The constraint filters out all entities that lack selling price in specified currency.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/price#price-in-currency"
};
var userFilter = {
	type: "FILTER",
	shortDescription: "The container for constraints that are controlled by the user (client UI widgets).  + It is used mainly to distinguish between user constraint (refining the search) and program defined  + constraints (considered mandatory), when the extra results are computed.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/behavioral#user-filter"
};
var attributeContains = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the text value of that attribute contains part of passed text (case-sensitive).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/string#attribute-contains"
};
var excluding = {
	type: "FILTER",
	shortDescription: "The constraint narrows hierarchy within parent constraint to exclude specified hierarchy subtrees from search.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#excluding"
};
var priceValidIn = {
	type: "FILTER",
	shortDescription: "The constraint checks if entity has selling price valid at the passed moment.",
	userDocsLink: "https://evitadb.io/documentation/filtering/price#price-valid-in"
};
var attributeLessThan = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute is less than the passed value.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-less-than"
};
var priceInPriceLists = {
	type: "FILTER",
	shortDescription: "The constraint filters out all entities that lack selling price in specified price lists.  + Order of price lists also defines priority for selecting the entity selling price - the price from first price  + list in the list will be used as a selling price for the entire entity.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/price#price-in-price-lists"
};
var entityLocaleEquals = {
	type: "FILTER",
	shortDescription: "The constraint if at least one of entity locales (derived from entity attributes or associated data) equals to the passed one.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/locale#entity-locale-equals"
};
var attributeGreaterThan = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute is greater than the passed value.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-greater-than"
};
var facetHaving = {
	type: "FILTER",
	shortDescription: "The container allowing to filter entities by having references to entities managed by evitaDB that  + match the inner filter constraint. This container resembles the SQL inner join clauses and works in cooperation  + with facet summary requirement.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/references#facet-having"
};
var or = {
	type: "FILTER",
	shortDescription: "The container that combines inner constraints with [logical OR](https://en.wikipedia.org/wiki/Logical_disjunction).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/logical#or"
};
var attributeEquals = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if they are both equal.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-equals"
};
var hierarchyWithinRoot = {
	type: "FILTER",
	shortDescription: "The constraint if entity is placed inside the defined hierarchy tree starting at the root of the tree (or has reference to any hierarchical entity in the tree).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#hierarchy-within-root"
};
var and = {
	type: "FILTER",
	shortDescription: "The container that combines inner constraints with [logical AND](https://en.wikipedia.org/wiki/Logical_conjunction).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/logical#and"
};
var attributeBetween = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute is within the passed range (both ends are inclusive).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-between"
};
var referenceHaving = {
	type: "FILTER",
	shortDescription: "The container allowing to filter entities by having references to entities managed by evitaDB that  + match the inner filter constraint. This container resembles the SQL inner join clauses.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/references#reference-having"
};
var not = {
	type: "FILTER",
	shortDescription: "The container that behaves as [logical NOT](https://en.wikipedia.org/wiki/Negation) for the inner constraint.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/logical#not"
};
var attributeIs = {
	type: "FILTER",
	shortDescription: "The constraint if value of the attribute is same as passed special value.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-is"
};
var attributeLessThanEquals = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute is less than or equals to the passed value.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-less-than-equals"
};
var having = {
	type: "FILTER",
	shortDescription: "The constraint narrows hierarchy within parent constraint to include specified hierarchy subtrees from search.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#having"
};
var attributeStartsWith = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the text value of that attributes starts with passed text. (case-sensitive)",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/string#attribute-starts-with"
};
var hierarchyWithin = {
	type: "FILTER",
	shortDescription: "The constraint if entity is placed inside the defined hierarchy tree (or has reference to any hierarchical entity in the tree).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#hierarchy-within"
};
var directRelation = {
	type: "FILTER",
	shortDescription: "The constraint limits hierarchy within parent constraint to take only directly related entities into an account.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#direct-relation"
};
var attributeEndsWith = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the text value of that attribute ends with passed text (case-sensitive).",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/string#attribute-ends-with"
};
var excludingRoot = {
	type: "FILTER",
	shortDescription: "The constraint limits hierarchy within parent constraint to exclude the entities directly related to the searched root node.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/hierarchy#excluding-root"
};
var attributeInSet = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the value of that attribute  + equals to at least one of the passed values.  + The constraint is equivalent to the multiple `equals` constraints combined with logical OR.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/comparable#attribute-in-set"
};
var entityPrimaryKeyInSet = {
	type: "FILTER",
	shortDescription: "The constraint checks if primary key of the entity equals to at least one of the passed values.  + The constraint is equivalent to one or more `equals` constraints combined with logical OR.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/constant#entity-primary-key-in-set"
};
var attributeInRange = {
	type: "FILTER",
	shortDescription: "Compares value of the attribute with passed value and checks if the range value of that  + attribute contains the passed value within its limits (both ends are inclusive).  + The constraint can be used only for Range data type values.",
	userDocsLink: "https://evitadb.io/documentation/query/filtering/range#attribute-in-range"
};
var entityProperty = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned references by applying ordering constraint on referenced entity.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/reference#entity-property"
};
var entityPrimaryKeyInFilter = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by ordering of the values specified `entityPrimaryKeysInSet` in filter.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/constant#exact-entity-primary-key-order-used-in-filter"
};
var referenceProperty = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities or references by attribute specified on its reference in natural order.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/reference#reference-property"
};
var priceNatural = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by selected price for sale.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/price#price-natural"
};
var entityPrimaryKeyExact = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by ordering of the values specified in arguments.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/constant#exact-entity-primary-key-order"
};
var attributeNatural = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by natural ordering of the values in the specified attribute.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/comparable#attribute-natural"
};
var orderGroupBy = {
	type: "ORDER",
	shortDescription: "The container encapsulates order constraints that control the order of the facet groups in facet summary.",
	userDocsLink: "https://evitadb.io/documentation/query/basics#order-by"
};
var orderBy = {
	type: "ORDER",
	shortDescription: "The container encapsulates inner order constraints into one main constraint that is required by the query.",
	userDocsLink: "https://evitadb.io/documentation/query/basics#order-by"
};
var attributeSetInFilter = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by ordering of the values specified `attributeInSet` in filter sharing the same attribute name.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/constant#exact-entity-attribute-value-order-used-in-filter"
};
var attributeSetExact = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by ordering of the values specified in arguments matching the entity attribute of specified name.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/constant#exact-entity-attribute-value-order"
};
var entityGroupProperty = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned references by applying ordering constraint on referenced entity group.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/reference#entity-group-property"
};
var entityPrimaryKeyNatural = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities by primary key in specific order.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/comparable#primary-key-natural"
};
var random = {
	type: "ORDER",
	shortDescription: "The constraint sorts returned entities randomly.",
	userDocsLink: "https://evitadb.io/documentation/query/ordering/random#random"
};
var hierarchyOfReference = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of hierarchy statistics (how many matching children the hierarchy nodes have) of referenced hierarchical entities into response.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#hierarchy-of-reference"
};
var priceType = {
	type: "REQUIRE",
	shortDescription: "The constraint specifies which price type (with/without tax) will be used for handling filtering and sorting constraints.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/price#price-type"
};
var dataInLocales = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching of the localized attributes or associated data in different/additional locales than the locale specified in filtering constraints (if any at all).",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#data-in-locales"
};
var hierarchyOfSelf = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of hierarchy statistics (how many matching children the hierarchy nodes have) of same hierarchical collection into response.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#hierarchy-of-self"
};
var fromNode = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the hierarchy subtree starting at pivot node.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#from-node"
};
var distance = {
	type: "REQUIRE",
	shortDescription: "The constraint limits the traversing in stop at container at specified distance (number of nodes in path).",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#distance"
};
var stopAt = {
	type: "REQUIRE",
	shortDescription: "The constraint defines the traversal stop condition that limits the scope of the returned hierarchy tree.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#stop-at"
};
var facetSummaryOfReference = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of facet summary of all facet in searched scope into response with custom \\fetching\\ settings for specific reference.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/facet#facet-summary-of-reference"
};
var level = {
	type: "REQUIRE",
	shortDescription: "The constraint limits the traversing in stop at container at specified level from root.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#level"
};
var facetGroupsDisjunction = {
	type: "REQUIRE",
	shortDescription: "Sets relation of facets in the specified groups towards facets in different groups to [logical OR](https://en.wikipedia.org/wiki/Logical_disjunction) .",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/facet#facet-groups-disjunction"
};
var children = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the hierarchy subtree starting at currently requested hierarchy node in filter by constraint.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#children"
};
var facetGroupsConjunction = {
	type: "REQUIRE",
	shortDescription: "Sets inter-facets relation within the specified groups to [logical AND](https://en.wikipedia.org/wiki/Logical_conjunction).",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/facet#facet-groups-conjunction"
};
var fromRoot = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the hierarchy subtree starting at root level.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#from-root"
};
var queryTelemetry = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of query telemetry (explaining what operations were performed and how long they took) in extra results of the response.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/debug#query-telemetry"
};
var priceHistogram = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of the [histogram](https://en.wikipedia.org/wiki/Histogram) of price for sale into response.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/histogram#price-histogram"
};
var associatedDataContent = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching the entity associated data of specified names into the returned entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#associated-data-content"
};
var hierarchyContent = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching parent hierarchy entity parent chain and its bodies into returned main entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#hierarchy-content"
};
var statistics = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the count of children for each returned hierarchy node.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#statistics"
};
var facetGroupsNegation = {
	type: "REQUIRE",
	shortDescription: "[Negates](https://en.wikipedia.org/wiki/Negation) the meaning of selected facets in specified  + facet groups in the sense that their selection would return entities that don't have any of those facets.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/facet#facet-groups-negation"
};
var entityFetch = {
	type: "REQUIRE",
	shortDescription: "Returns richer entities instead of just entity references (empty container returns only entity body).",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#entity-fetch"
};
var require$1 = {
	type: "REQUIRE",
	shortDescription: "The container encapsulates inner require constraints into one main constraint that is required by the query",
	userDocsLink: "https://evitadb.io/documentation/query/basics#require"
};
var entityGroupFetch = {
	type: "REQUIRE",
	shortDescription: "Returns richer group entities instead of just entity references (empty container returns only entity body).",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#entity-group-fetch"
};
var node = {
	type: "REQUIRE",
	shortDescription: "The constraint allows to locate the pivot hierarchy node.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#node"
};
var attributeContent = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching the entity attributes into the returned entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#attribute-content"
};
var strip = {
	type: "REQUIRE",
	shortDescription: "The constraint specifies which strip (subset) of found entities will be returned.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/paging#strip"
};
var siblings = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the sibling axis for currently requested hierarchy node in filter by constraint or processed node by hierarchy parents axis.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#siblings"
};
var priceContent = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching the entity prices into the returned entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#price-content"
};
var page = {
	type: "REQUIRE",
	shortDescription: "The constraint specifies which page of found entities will be returned.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/paging#page"
};
var parents = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computing the hierarchy parent axis starting at currently requested hierarchy node in filter by constraint.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/hierarchy#parents"
};
var referenceContent = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers fetching referenced entity bodies into returned main entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/fetching#reference-content"
};
var attributeHistogram = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of the [histogram](https://en.wikipedia.org/wiki/Histogram) of specified attributes into response.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/histogram#attribute-histogram"
};
var facetSummary = {
	type: "REQUIRE",
	shortDescription: "The constraint triggers computation of facet summary of all facet in searched scope into response with default \\fetching\\ settings for all referenced entities.",
	userDocsLink: "https://evitadb.io/documentation/query/requirements/facet#facet-summary"
};
var constraints = {
	collection: collection,
	filterGroupBy: filterGroupBy,
	attributeGreaterThanEquals: attributeGreaterThanEquals,
	filterBy: filterBy,
	priceBetween: priceBetween,
	entityHaving: entityHaving,
	priceInCurrency: priceInCurrency,
	userFilter: userFilter,
	attributeContains: attributeContains,
	excluding: excluding,
	priceValidIn: priceValidIn,
	attributeLessThan: attributeLessThan,
	priceInPriceLists: priceInPriceLists,
	entityLocaleEquals: entityLocaleEquals,
	attributeGreaterThan: attributeGreaterThan,
	facetHaving: facetHaving,
	or: or,
	attributeEquals: attributeEquals,
	hierarchyWithinRoot: hierarchyWithinRoot,
	and: and,
	attributeBetween: attributeBetween,
	referenceHaving: referenceHaving,
	not: not,
	attributeIs: attributeIs,
	attributeLessThanEquals: attributeLessThanEquals,
	having: having,
	attributeStartsWith: attributeStartsWith,
	hierarchyWithin: hierarchyWithin,
	directRelation: directRelation,
	attributeEndsWith: attributeEndsWith,
	excludingRoot: excludingRoot,
	attributeInSet: attributeInSet,
	entityPrimaryKeyInSet: entityPrimaryKeyInSet,
	attributeInRange: attributeInRange,
	entityProperty: entityProperty,
	entityPrimaryKeyInFilter: entityPrimaryKeyInFilter,
	referenceProperty: referenceProperty,
	priceNatural: priceNatural,
	entityPrimaryKeyExact: entityPrimaryKeyExact,
	attributeNatural: attributeNatural,
	orderGroupBy: orderGroupBy,
	orderBy: orderBy,
	attributeSetInFilter: attributeSetInFilter,
	attributeSetExact: attributeSetExact,
	entityGroupProperty: entityGroupProperty,
	entityPrimaryKeyNatural: entityPrimaryKeyNatural,
	random: random,
	hierarchyOfReference: hierarchyOfReference,
	priceType: priceType,
	dataInLocales: dataInLocales,
	hierarchyOfSelf: hierarchyOfSelf,
	fromNode: fromNode,
	distance: distance,
	stopAt: stopAt,
	facetSummaryOfReference: facetSummaryOfReference,
	level: level,
	facetGroupsDisjunction: facetGroupsDisjunction,
	children: children,
	facetGroupsConjunction: facetGroupsConjunction,
	fromRoot: fromRoot,
	queryTelemetry: queryTelemetry,
	priceHistogram: priceHistogram,
	associatedDataContent: associatedDataContent,
	hierarchyContent: hierarchyContent,
	statistics: statistics,
	facetGroupsNegation: facetGroupsNegation,
	entityFetch: entityFetch,
	require: require$1,
	entityGroupFetch: entityGroupFetch,
	node: node,
	attributeContent: attributeContent,
	strip: strip,
	siblings: siblings,
	priceContent: priceContent,
	page: page,
	parents: parents,
	referenceContent: referenceContent,
	attributeHistogram: attributeHistogram,
	facetSummary: facetSummary
};

class EvitaQLQueryMode {
    constructor() { }
}
class EvitaQLConstraintListMode {
    constructor(listType) {
        this.listType = listType;
    }
}
exports.ConstraintListType = void 0;
(function (ConstraintListType) {
    ConstraintListType["Filter"] = "FILTER";
    ConstraintListType["Order"] = "ORDER";
    ConstraintListType["Require"] = "REQUIRE";
})(exports.ConstraintListType || (exports.ConstraintListType = {}));

function evitaQLCompletion(lang, config) {
    var _a;
    let completionList;
    if (config.mode instanceof EvitaQLQueryMode) {
        completionList = [
            createCompletion('query', 'Query is the root construct for querying data.'),
            ...Object.keys(constraints).map(it => createCompletion(it))
        ];
    }
    else if (config.mode instanceof EvitaQLConstraintListMode) {
        let constraintKeys;
        if (config.mode.listType === exports.ConstraintListType.Filter) {
            constraintKeys = Object.keys(constraints).filter(it => {
                const constraint = constraints[it];
                return constraint.type === exports.ConstraintListType.Filter && it !== 'filterBy';
            });
        }
        else if (config.mode.listType === exports.ConstraintListType.Order) {
            constraintKeys = Object.keys(constraints).filter(it => {
                const constraint = constraints[it];
                return constraint.type === exports.ConstraintListType.Order && it !== 'orderBy';
            });
        }
        else if (config.mode.listType === exports.ConstraintListType.Require) {
            constraintKeys = Object.keys(constraints).filter(it => {
                const constraint = constraints[it];
                return constraint.type === exports.ConstraintListType.Require && it !== 'require';
            });
        }
        else {
            throw new Error(`Unsupported constraint list type '${config.mode.listType}'`);
        }
        completionList = constraintKeys.map(it => createCompletion(it));
    }
    else {
        throw new Error(`Unsupported mode '${(_a = config.mode) === null || _a === void 0 ? void 0 : _a.toString()}'`);
    }
    return lang.data.of({
        autocomplete: autocomplete.completeFromList(completionList)
    });
}
function createCompletion(label, info) {
    const constraintDefinition = constraints[label];
    return {
        label,
        detail: '(...)',
        type: 'function',
        info: info ? info : constraintDefinition['shortDescription'] + "\n\n[Check detailed documentation](" + constraintDefinition['userDocsLink'] + ")",
        apply: (view, completion, from, to) => {
            view.dispatch({
                changes: { from, to, insert: label + '()' },
                selection: { anchor: from + label.length + 1 }
            });
        }
    };
}

const evitaQLLinter = lint.linter(view => {
    const diagnostics = [];
    language.syntaxTree(view.state).cursor().iterate(node => {
        if (node.type.isError) {
            diagnostics.push({
                from: node.from,
                to: node.to,
                severity: 'error',
                message: 'Syntax error.'
            });
        }
    });
    return diagnostics;
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const parser = lr.LRParser.deserialize({
  version: 14,
  states: "(WOYQPOOQ_QQOOOdQPO'#C_QOQPOOOiQPO'#CrQnQPOOOsQPO'#CbOOQO,58y,58yOOQO,59^,59^O#PQQO'#CdO_QQO'#CvQnQPOOOiQPO'#CcO#WQPO,58|O#`QQO'#DROOQO'#Co'#CoOOQO'#DQ'#DQOOQO'#DP'#DPOOQO,59O,59OO#nQPO,59OOOQO,59b,59bOOQO-E6t-E6tOOQO,58},58}OsQPO'#CuO#vQPO1G.hOOQO1G.h1G.hO$OQPO,59mO$^QQO,59qO$cQQO,59rO$hQQO,59sO!RQQO'#CtO$mQPO1G.jOOQO1G.j1G.jOOQO,59a,59aOOQO-E6s-E6sOOQO7+$S7+$SO$uQPO1G/XO%aQPO1G/]O%fQPO1G/^O%kQPO1G/_O%pQPO1G/]O%xQPO1G/^O&QQPO1G/_OOQO,59`,59`OOQO-E6r-E6rOOQO7+$U7+$UOOQO7+$w7+$wOOQO7+$x7+$xOOQO7+$y7+$yO&YQPO7+$wO&_QPO7+$xO&dQPO7+$yOOQO<<Hc<<HcOOQO<<Hd<<HdOOQO<<He<<He",
  stateData: "&x~OmOSPOS~OnQO~O|SO~OTUO~OTXO~O}YO~Oo[Op[Oq[Or[O~OX`OY`OZ`O[`O]`O^`O_`O``Oa`Ob`Od`Oe`Ov^O|SO~OSbO~P!ROSiO}gO~O[mO]lObkOwjO~OSpO}nO~OSsO}gO~O[wO]vObuOxtO~OwxO~OwyO~OwzO~OS}O}nO~OSuiSyiSziS{i}ui}yi}zi}{i~Ox!OO~Ox!PO~Ox!QO~Ob!ROx!OO~O]!SOx!PO~O[!TOx!QO~Ox!UO~Ox!VO~Ox!WO~O|Zba_`][^deYX]~",
  goto: "#a|PPP}PP!Q!T!ZPPPPPPPPPP!aPP!eP!o!u!{PPPPPPPP#R#X#]PPP#]#]#]RRORVQQ]URqgQWSRf[T`XnQTPSaXnRdYQocR|oQh]RrhQZTReZQcXR{nTaXnT_Xn",
  nodeNames: "⚠ Comment QueryRequest Query ArgsClosing ArgsOpening QueryBody RootConstraint ConstraintBody PositionalParameter NamedParameter String Int Float Boolean Date Time DateTime OffsetDateTime Range Uuid Enum Constraint ConstraintListRequest",
  maxTerm: 45,
  nodeProps: [
    ["openedBy", 4,"ArgsOpening"],
    ["closedBy", 5,"ArgsClosing"]
  ],
  skippedNodes: [0,1],
  repeatNodeCount: 3,
  tokenData: "#@l~RuXY#fYZ#f]^#fpq#frs#wwx&axy'xyz'}|}(S}!O(Z!P!Q(z!Q![)i!a!b2r!b!c2w!c!}3]!}#O3n#P#Q3s#T#U3x#U#V1`#V#WJ{#W#X!#Z#X#Y!*c#Y#Z!5r#Z#[1`#[#]!Au#]#`1`#`#a!It#a#b1`#b#c!K`#c#d!L[#d#e!Ng#e#f#*_#f#g#-W#g#h#7c#h#i#>_#i#j#?T#j#o1`~#kSm~XY#fYZ#f]^#fpq#f~#zWpq#wqr#wrs$ds#O#w#O#P$i#P;'S#w;'S;=`&Z<%lO#w~$iOZ~~$lXrs#w!P!Q#w#O#P#w#U#V#w#Y#Z#w#b#c#w#f#g#w#h#i#w#i#j%X~%[R!Q![%e!c!i%e#T#Z%e~%hR!Q![%q!c!i%q#T#Z%q~%tR!Q![%}!c!i%}#T#Z%}~&QR!Q![#w!c!i#w#T#Z#w~&^P;=`<%l#w~&dVOw&awx$dx#O&a#O#P&y#P;'S&a;'S;=`'r<%lO&a~&|RO;'S&a;'S;=`'V;=`O&a~'YWOw&awx$dx#O&a#O#P&y#P;'S&a;'S;=`'r;=`<%l&a<%lO&a~'uP;=`<%l&a~'}OT~~(SOS~R(ZOwQ}P~(^P!Q![(a~(fQ[~!O!P(l!Q![(a~(oP!Q![(r~(wP]~!Q![(r~(}P!P!Q)Q~)VSP~OY)QZ;'S)Q;'S;=`)c<%lO)Q~)fP;=`<%l)Q~)nS[~}!O)z!O!P(l!Q![+q#T#o1`Q)}Q!Q![*T#T#o*TQ*WR}!O*a!Q![*T#T#o*TQ*dQ!Q![*j#T#o*jQ*mR}!O*v!Q![*j#T#o*jQ*yQ!Q![+P#T#o+PQ+SR}!O+]!Q![+P#T#o+PQ+`Q!Q![+f#T#o+fQ+kQdQ!Q![+f#T#o+f~+vT[~}!O)z!O!P(l!Q![,V![!]1l#T#o1`~,[S[~}!O)z!O!P(l!Q![,h#T#o1`~,mS[~}!O,y!O!P(l!Q![0}#T#o1`~,|Q!Q![-S#T#o*T~-VR}!O*a!Q![-`#T#o*T~-cR}!O-l!Q![*T#T#o*T~-oQ!Q![-u#T#o*j~-xR}!O*v!Q![.R#T#o*j~.WS_~}!O*v!Q![*j!v!w.d#T#o*j~.gP!Q![.j~.mP!Q![.p~.sP![!].v~.yP!Q![.|~/PP!Q![/S~/VP![!]/Y~/]P!Q![/`~/cP!Q![/f~/kRa~{|/t}!O/t!O!P0i~/wP!Q![/z~/}P!Q![0Q~0TP![!]0W~0ZP!Q![0^~0aP!Q![0d~0iOb~~0lP!Q![0o~0tRa~{|/t}!O/t!Q![0o~1SS[~}!O)z!O!P(l!Q![0}#T#o1`Q1cR}!O)z!Q![1`#T#o1`~1oP!Q![1r~1uP!Q![1x~1{P![!]2O~2RP!Q![2U~2XP!Q![2[~2aP`~!O!P2d~2gP!Q![2j~2oP`~!Q![2j~2wOX~~2zP#T#o2}~3SRY~!Q![2}!c!}2}#T#o2}~3bQe~!c!}3]#R#S3h~3kP!c!}3]~3sOv~~3xOx~Q3{W}!O)z!Q![1`#T#b1`#b#c4e#c#g1`#g#h5V#h#i:b#i#o1`Q4hT}!O)z!Q![1`#T#W1`#W#X4w#X#o1`Q4|R|Q}!O)z!Q![1`#T#o1`Q5YT}!O)z!Q![1`#T#g1`#g#h5i#h#o1`Q5lT}!O)z!Q![1`#T#c1`#c#d5{#d#o1`Q6OT}!O)z!Q![1`#T#V1`#V#W6_#W#o1`Q6bT}!O)z!Q![1`#T#]1`#]#^6q#^#o1`Q6tS}!O)z!Q![1`#T#U7Q#U#o1`Q7TT}!O)z!Q![1`#T#h1`#h#i7d#i#o1`Q7gT}!O)z!Q![1`#T#X1`#X#Y7v#Y#o1`Q7yT}!O)z!Q![1`#T#W1`#W#X8Y#X#o1`Q8]S}!O)z!Q![1`!f!g8i#T#o1`Q8lP#T#U8oQ8rP#h#i8uQ8xP#T#U8{Q9OP!e!f9RQ9UP#c#d9XQ9[P#b#c9_Q9bP#h#i9eQ9hP#X#Y9kQ9nP#b#c9qQ9tP#h#i9wQ9|P|Q!c!d:PQ:SP#`#a:VQ:YP#`#a:]Q:bO|QQ:eT}!O)z!Q![1`#T#h1`#h#i:t#i#o1`Q:wT}!O)z!Q![1`#T#f1`#f#g;W#g#o1`Q;ZT}!O)z!Q![1`#T#]1`#]#^;j#^#o1`Q;mT}!O)z!Q![1`#T#U1`#U#V;|#V#o1`Q<PT}!O)z!Q![1`#T#i1`#i#j<`#j#o1`Q<cT}!O)z!Q![1`#T#h1`#h#i<r#i#o1`Q<uT}!O)z!Q![1`#T#X1`#X#Y=U#Y#o1`Q=X[}!O)z!Q![1`!d!e=}!e!f>s!g!h?r!i!jB[!j!kD[!k!lE^!n!oGo!p!qHR!u!vHq#T#o1`Q>QP#X#Y>TQ>WP#h#i>ZQ>^P#k#l>aQ>dP#X#Y>gQ>jP#X#Y>mQ>pP#b#c:]Q>vP#c#d>yQ>|P#b#c?PQ?SP#h#i?VQ?YQ#T#U?`#X#Y9kQ?cP#]#^?fQ?iP#b#c?lQ?oP#g#h:]Q?uQ#b#c?{#e#f@qQ@OP#W#X@RQ@UP#g#h@XQ@[P!y!z@_Q@bP#]#^@eQ@hP#h#i@kQ@nP#[#]:]Q@tP#i#j@wQ@zP#T#U@}QAQP#`#aATQAWP#g#hAZQA`Q|Q!h!iAf!v!wBOQAiP#T#UAlQAoP#`#aArQAuP#g#hAxQA{P#X#Y:]QBRP#f#gBUQBXP#i#jAxQB_P#f#gBbQBeP#X#YBhQBkP#T#UBnQBqP#h#iBtQBwP#X#YBzQB}P#f#gCQQCTP!v!wCWQCZP#[#]C^QCaP#T#UCdQCgP#b#cCjQCoP|Q!g!hCrQCuP#e#fCxQC{P#i#jDOQDRP#T#UDUQDXP#`#a?lQD_P#]#^DbQDeP#g#hDhQDkP#h#iDnQDqP#c#dDtQDwP#Z#[DzQD}P#f#gEQQETP#T#UEWQEZP#a#b:]QEaQ#b#cEg#g#hFzQEjQ!t!uEp!u!vFnQEsP#T#UEvQEyP#b#cE|QFPP#Z#[FSQFVP#X#YFYQF_P|Q!p!qFbQFeP#c#dFhQFkP#k#l:]QFqP#X#YFtQFwP#h#i:]QGPP|Q!p!qGSQGVQ#c#dG]#i#j:PQG`P#h#iGcQGfP!p!qGiQGlP#i#j:PQGrP#X#YGuQGxP#g#hG{QHOP#g#hCQQHUP#T#UHXQH[P#h#iH_QHbP#i#jHeQHhP#f#gHkQHnP#T#U:VQHtQ#X#YHz#h#iJiQH}P#h#iIQQITQ!g!hIZ!k!lImQI^P#l#mIaQIdP#T#UIgQIjP#V#WFtQIpP#b#cIsQIvP!h!iIyQI|P#]#^JPQJSP#`#aJVQJYP#h#iJ]QJ`P#X#YJcQJfP#f#g:]QJlP#T#UJoQJrP#f#gJuQJxP#h#i@RRKOV}!O)z!Q![1`#T#[1`#[#]Ke#]#c1`#c#dMu#d#o1`QKhT}!O)z!Q![1`#T#]1`#]#^Kw#^#o1`QKzT}!O)z!Q![1`#T#`1`#`#aLZ#a#o1`QL^T}!O)z!Q![1`#T#W1`#W#XLm#X#o1`QLpT}!O)z!Q![1`#T#f1`#f#gMP#g#o1`QMST}!O)z!Q![1`#T#X1`#X#YMc#Y#o1`QMfT}!O)z!Q![1`#T#b1`#b#c4w#c#o1`RMxT}!O)z!Q![1`#T#`1`#`#aNX#a#o1`RN[T}!O)z!Q![1`#T#`1`#`#aNk#a#o1`RNnT}!O)z!Q![1`#T#X1`#X#YN}#Y#o1`R! QT}!O)z!Q![1`#T#V1`#V#W! a#W#o1`R! dT}!O)z!Q![1`#T#h1`#h#i! s#i#o1`R! vT}!O)z!Q![1`#T#]1`#]#^!!V#^#o1`R!!YT}!O)z!Q![1`#T#c1`#c#d!!i#d#o1`R!!lT}!O)z!Q![1`#T#b1`#b#c!!{#c#o1`R!#QRoP}!O)z!Q![1`#T#o1`Q!#^U}!O)z!Q![1`#T#U!#p#U#]1`#]#^!%t#^#o1`Q!#sT}!O)z!Q![1`#T#h1`#h#i!$S#i#o1`Q!$VS}!O)z!Q![1`#T#U!$c#U#o1`Q!$fS}!O)z!Q![1`!k!l!$r#T#o1`Q!$uP#b#c!$xQ!${P!n!o!%OQ!%RP#c#d!%UQ!%XP#V#W!%[Q!%_P#T#U!%bQ!%eP#`#a!%hQ!%kP#X#Y!%nQ!%qP#g#h9wQ!%wU}!O)z!Q![1`#T#f1`#f#g!&Z#g#h!(h#h#o1`Q!&^T}!O)z!Q![1`#T#X1`#X#Y!&m#Y#o1`Q!&pT}!O)z!Q![1`#T#V1`#V#W!'P#W#o1`Q!'ST}!O)z!Q![1`#T#h1`#h#i!'c#i#o1`Q!'fS}!O)z!Q![1`!t!u!'r#T#o1`Q!'uP#X#Y!'xQ!'{P#`#a!(OQ!(RP#T#U!(UQ!(XP#h#i!([Q!(_P#]#^!(bQ!(eP#c#d>mQ!(kT}!O)z!Q![1`#T#h1`#h#i!(z#i#o1`Q!(}S}!O)z!Q![1`#T#U!)Z#U#o1`Q!)^T}!O)z!Q![1`#T#b1`#b#c!)m#c#o1`Q!)pT}!O)z!Q![1`#T#V1`#V#W!*P#W#o1`Q!*ST}!O)z!Q![1`#T#X1`#X#Y4w#Y#o1`Q!*fV}!O)z!Q![1`#T#b1`#b#c!*{#c#l1`#l#m!2a#m#o1`Q!+OT}!O)z!Q![1`#T#h1`#h#i!+_#i#o1`Q!+bT}!O)z!Q![1`#T#]1`#]#^!+q#^#o1`Q!+tT}!O)z!Q![1`#T#h1`#h#i!,T#i#o1`Q!,WT}!O)z!Q![1`#T#m1`#m#n!,g#n#o1`Q!,jW}!O)z!Q![1`!h!i!-S!i!j!-f!j!k!/T!n!o!/s!r!s!0i#T#o1`Q!-VP#X#Y!-YQ!-]P#h#i!-`Q!-cP#V#W@kQ!-iP#f#g!-lQ!-oP#c#d!-rQ!-uP#i#j!-xQ!-{P#d#e!.OQ!.RQ!h!i!-S!r!s!.XQ!.[P#f#g!._Q!.bP#c#d!.eQ!.hP#d#e!.kQ!.nP#X#Y!.qQ!.tP#f#g!.wQ!.zP#h#i!.}Q!/QP#m#n:]Q!/WP#T#U!/ZQ!/^P#j#k!/aQ!/dP#]#^!/gQ!/jP#b#c!/mQ!/pP#Z#[:]Q!/vP#c#d!/yQ!/|P#V#W!0PQ!0SP#T#U!0VQ!0YP#`#a!0]Q!0`P#X#Y!0cQ!0fP!g!hCrQ!0lP#f#g!0oQ!0rQ#]#^!0x#c#d!.eQ!0{P#a#b!1OQ!1RP#T#U!1UQ!1XP#f#g!1[Q!1_P#m#n!1bQ!1eP!m!n!1hQ!1kP#X#Y!1nQ!1qP#m#n!1tQ!1wR!g!hIZ!k!l!2Q!p!qHRQ!2TP#b#c!2WQ!2ZQ!h!iIy!u!vFnQ!2dT}!O)z!Q![1`#T#V1`#V#W!2s#W#o1`Q!2vT}!O)z!Q![1`#T#`1`#`#a!3V#a#o1`Q!3YT}!O)z!Q![1`#T#i1`#i#j!3i#j#o1`Q!3lT}!O)z!Q![1`#T#W1`#W#X!3{#X#o1`Q!4OT}!O)z!Q![1`#T#]1`#]#^!4_#^#o1`Q!4bT}!O)z!Q![1`#T#b1`#b#c!4q#c#o1`Q!4tT}!O)z!Q![1`#T#Z1`#Z#[!5T#[#o1`Q!5YS|Q}!O)z!Q![1`!t!u!5f#T#o1`Q!5iP#c#d!5lQ!5oP#c#dFt~!5uW}!O)z!Q![1`#T#U!6_#U#]1`#]#^!=h#^#f1`#f#g!@a#g#o1`~!6bV}!O)z!Q![1`#T#V1`#V#W!6w#W#`1`#`#a!<d#a#o1`Q!6zT}!O)z!Q![1`#T#X1`#X#Y!7Z#Y#o1`Q!7^T}!O)z!Q![1`#T#h1`#h#i!7m#i#o1`Q!7pU}!O)z!Q![1`!i!j!8S!j!k!/T!u!v!:^#T#o1`Q!8VP#f#g!8YQ!8]P#c#d!8`Q!8cP#i#j!8fQ!8iP#d#e!8lQ!8oP#g#h!8rQ!8uR!e!f!9O!f!g!9t!p!q!:QQ!9RP#c#d!9UQ!9XP#b#c!9[Q!9_P#^#_!9bQ!9eP#i#j!9hQ!9kP#b#c!9nQ!9qP#V#W!(UQ!9wP#]#^!9zQ!9}P#g#h!9[Q!:TP#X#Y!:WQ!:ZP#Z#[!(OQ!:aP#i#j!:dQ!:gP#a#b!:jQ!:mP#a#b!:pQ!:sP#T#U!:vQ!:yP#f#g!:|Q!;PP#m#n!;SQ!;XP|Q!q!r!;[Q!;_P#Y#Z!;bQ!;eP!t!u!;hQ!;kP#X#Y!;nQ!;qP#Y#Z!;tQ!;wP#X#Y!;zQ!;}P#f#g!<QQ!<TP#X#Y!<WQ!<ZP#b#c!<^Q!<aP#V#WAx~!<gT}!O)z!Q![1`#T#g1`#g#h!<v#h#o1`~!<yT}!O)z!Q![1`#T#X1`#X#Y!=Y#Y#o1`~!=_R^~}!O)z!Q![1`#T#o1`~!=kT}!O)z!Q![1`#T#`1`#`#a!=z#a#o1`~!=}T}!O)z!Q![1`#T#h1`#h#i!>^#i#o1`~!>aT}!O)z!Q![1`#T#X1`#X#Y!>p#Y#o1`~!>sT}!O)z!Q![1`#T#f1`#f#g!?S#g#o1`~!?VT}!O)z!Q![1`!d!e!?f!i!j!?q#T#o1`~!?iP#m#n!?l~!?qOp~Q!?tP#f#g!?wQ!?zP#c#d!?}Q!@QP#i#j!@TQ!@WP#d#e!@ZQ!@^P!d!e!.}Q!@dT}!O)z!Q![1`#T#c1`#c#d!@s#d#o1`Q!@vT}!O)z!Q![1`#T#a1`#a#b!AV#b#o1`Q!AYT}!O)z!Q![1`!p!q!Ai!t!u!5f#T#o1`Q!AlP#c#d!AoQ!ArP#W#XAxQ!AxU}!O)z!Q![1`#T#U!B[#U#]1`#]#^!Cv#^#o1`Q!B_T}!O)z!Q![1`#T#j1`#j#k!Bn#k#o1`Q!BqT}!O)z!Q![1`#T#]1`#]#^!CQ#^#o1`Q!CTT}!O)z!Q![1`#T#b1`#b#c!Cd#c#o1`Q!CgT}!O)z!Q![1`#T#Z1`#Z#[4w#[#o1`Q!CyT}!O)z!Q![1`#T#X1`#X#Y!DY#Y#o1`Q!D]T}!O)z!Q![1`#T#f1`#f#g!Dl#g#o1`Q!DoS}!O)z!Q![1`#T#U!D{#U#o1`Q!EOT}!O)z!Q![1`#T#f1`#f#g!E_#g#o1`Q!EbT}!O)z!Q![1`#T#V1`#V#W!Eq#W#o1`Q!EtT}!O)z!Q![1`#T#[1`#[#]!FT#]#o1`Q!FWT}!O)z!Q![1`#T#m1`#m#n!Fg#n#o1`Q!FjU}!O)z!Q![1`!e!f!F|!q!r!Gl!y!z!H_#T#o1`Q!GPP#c#d!GSQ!GVP#b#c!GYQ!G]P#h#i!G`Q!GcP#X#Y!GfQ!GiP#b#cFtQ!GoP#Y#Z!GrQ!GuQ!t!u!;h!u!v!G{Q!HOP#X#Y!HRQ!HUP#`#a!HXQ!H[P#Y#Z:]Q!HbP#]#^!HeQ!HhP#h#i!HkQ!HnP#[#]!HqQ!HtP#]#^!HwQ!HzP#b#c!H}Q!ISQ|Q!t!u!IY!u!v!G{Q!I]P#c#d!I`Q!IcP#c#d!IfQ!IiP#h#i!IlQ!IqP|Q!u!v!G{Q!IwT}!O)z!Q![1`#T#X1`#X#Y!JW#Y#o1`Q!JZT}!O)z!Q![1`#T#j1`#j#k!Jj#k#o1`Q!JmT}!O)z!Q![1`#T#X1`#X#Y!J|#Y#o1`Q!KPT}!O)z!Q![1`#T#`1`#`#a4w#a#o1`Q!KcT}!O)z!Q![1`#T#c1`#c#d!Kr#d#o1`Q!KuV}!O)z!Q![1`#T#W1`#W#X!*P#X#h1`#h#i4w#i#o1`R!L_T}!O)z!Q![1`#T#f1`#f#g!Ln#g#o1`R!LsT|Q}!O)z!Q![1`#T#W1`#W#X!MS#X#o1`R!MVT}!O)z!Q![1`#T#X1`#X#Y!Mf#Y#o1`R!MiT}!O)z!Q![1`#T#f1`#f#g!Mx#g#o1`R!M{T}!O)z!Q![1`!d!e!N[!i!j!?q#T#o1`P!N_P#m#n!NbP!NgOqPQ!NjU}!O)z!Q![1`#T#U!N|#U#f1`#f#g##Q#g#o1`Q# PV}!O)z!Q![1`#T#Z1`#Z#[!*P#[#f1`#f#g# f#g#o1`Q# iT}!O)z!Q![1`#T#X1`#X#Y# x#Y#o1`Q# {T}!O)z!Q![1`#T#b1`#b#c#![#c#o1`Q#!_T}!O)z!Q![1`#T#h1`#h#i#!n#i#o1`Q#!qT}!O)z!Q![1`#T#g1`#g#h4w#h#o1`Q##TT}!O)z!Q![1`#T#]1`#]#^##d#^#o1`Q##gT}!O)z!Q![1`#T#V1`#V#W##v#W#o1`Q##yT}!O)z!Q![1`#T#X1`#X#Y#$Y#Y#o1`Q#$]Y}!O)z!Q![1`!d!e=}!e!f#${!j!kD[!k!l#'U!p!qHR!v!w#)]!x!y#)i#T#o1`Q#%OP#c#d#%RQ#%UP#b#c#%XQ#%[P#h#i#%_Q#%bP#X#Y#%eQ#%hP#b#c#%kQ#%nP#h#i#%qQ#%vQ|Q!c!d:P!t!u#%|Q#&PP#X#Y#&SQ#&VP#g#h#&YQ#&]P#d#e#&`Q#&cP#X#Y#&fQ#&iP#V#W#&lQ#&oP#h#i#&rQ#&uP#]#^#&xQ#&{P#b#c#'OQ#'RP#Z#[IsQ#'XP#b#c#'[Q#'_Q!e!f#'e!r!s#(ZQ#'hP#i#j#'kQ#'nP#f#g#'qQ#'tP#f#g#'wQ#'zP#X#Y#'}Q#(QP#b#c#(TQ#(WP#V#W!.}Q#(^P#f#g#(aQ#(dP#]#^#(gQ#(jP#V#W#(mQ#(pP#X#Y#(sQ#(vP!n!o#(yQ#(|P#]#^#)PQ#)SP#g#h#)VQ#)YP#h#i?lQ#)`P#m#n#)cQ#)fP#d#eAxQ#)lP#T#U#)oQ#)rP#`#a#)uQ#)xP#]#^#){Q#*OP#W#X#*RQ#*UP!k!l#*XQ#*[P#b#cFYR#*bT}!O)z!Q![1`#T#i1`#i#j#*q#j#o1`R#*tT}!O)z!Q![1`#T#X1`#X#Y#+T#Y#o1`R#+WT}!O)z!Q![1`#T#f1`#f#g#+g#g#o1`R#+jT}!O)z!Q![1`#T#m1`#m#n#+y#n#o1`R#,OSnP}!O)z!Q![1`!v!w#,[#T#o1`Q#,_P#X#Y#,bQ#,eP#`#a#,hQ#,kP#X#Y#,nQ#,qP#a#b#,tQ#,wP#X#Y#,zQ#,}P#h#i#-QQ#-TP#f#g!.}R#-ZU}!O)z!Q![1`#T#U#-m#U#X1`#X#Y#/X#Y#o1`Q#-pT}!O)z!Q![1`#T#b1`#b#c#.P#c#o1`Q#.ST}!O)z!Q![1`#T#W1`#W#X#.c#X#o1`Q#.fT}!O)z!Q![1`#T#c1`#c#d#.u#d#o1`Q#.xT}!O)z!Q![1`#T#a1`#a#b4w#b#o1`R#/[V}!O)z!Q![1`#T#Y1`#Y#Z#/q#Z#e1`#e#f#5i#f#o1`Q#/tT}!O)z!Q![1`#T#X1`#X#Y#0T#Y#o1`Q#0WT}!O)z!Q![1`#T#f1`#f#g#0g#g#o1`Q#0jT}!O)z!Q![1`#T#X1`#X#Y#0y#Y#o1`Q#0|T}!O)z!Q![1`#T#b1`#b#c#1]#c#o1`Q#1`T}!O)z!Q![1`#T#V1`#V#W#1o#W#o1`Q#1rT}!O)z!Q![1`#T#X1`#X#Y#2R#Y#o1`Q#2UU}!O)z!Q![1`!e!f#2h!j!k!/T!r!s!.X#T#o1`Q#2kP#c#d#2nQ#2qP#b#c#2tQ#2wP#h#i#2zQ#2}P#X#Y#3QQ#3TP#b#c#3WQ#3ZP#h#i#3^Q#3cQ|Q!c!d#3i!y!z#3}Q#3lP#`#a#3oQ#3rP#`#a#3uQ#3zP|Q!y!z#3}Q#4QP#]#^#4TQ#4WP#h#i#4ZQ#4^P#[#]#4aQ#4dP!c!d#4gQ#4jP#h#i#4mQ#4pP#h#i#4sQ#4vP#f#g#4yQ#4|P#]#^#5PQ#5SP#U#V#5VQ#5YP#i#j#5]Q#5`P#h#i#5cQ#5fP#X#Y?lR#5lT}!O)z!Q![1`#T#i1`#i#j#5{#j#o1`R#6OT}!O)z!Q![1`#T#]1`#]#^#6_#^#o1`R#6bT}!O)z!Q![1`#T#f1`#f#g#6q#g#o1`R#6tT}!O)z!Q![1`#T#X1`#X#Y#7T#Y#o1`R#7YRrP}!O)z!Q![1`#T#o1`Q#7fV}!O)z!Q![1`#T#]1`#]#^#7{#^#h1`#h#i#9y#i#o1`Q#8OT}!O)z!Q![1`#T#U1`#U#V#8_#V#o1`Q#8bT}!O)z!Q![1`#T#`1`#`#a#8q#a#o1`Q#8tT}!O)z!Q![1`#T#]1`#]#^#9T#^#o1`Q#9WT}!O)z!Q![1`#T#b1`#b#c#9g#c#o1`Q#9jT}!O)z!Q![1`#T#Z1`#Z#[#!n#[#o1`Q#9|W}!O)z!Q![1`#T#U#:f#U#c1`#c#d#<v#d#f1`#f#g#=i#g#o1`Q#:iT}!O)z!Q![1`#T#h1`#h#i#:x#i#o1`Q#:{T}!O)z!Q![1`#T#]1`#]#^#;[#^#o1`Q#;_T}!O)z!Q![1`#T#g1`#g#h#;n#h#o1`Q#;qT}!O)z!Q![1`#T#h1`#h#i#<Q#i#o1`Q#<TT}!O)z!Q![1`#T#]1`#]#^#<d#^#o1`Q#<gT}!O)z!Q![1`#T#V1`#V#W#!n#W#o1`Q#<yT}!O)z!Q![1`#T#d1`#d#e#=Y#e#o1`Q#=]S}!O)z!Q![1`!c!dFt#T#o1`Q#=lT}!O)z!Q![1`#T#]1`#]#^#={#^#o1`Q#>OT}!O)z!Q![1`#T#d1`#d#e4w#e#o1`~#>bT}!O)z!Q![1`#T#f1`#f#g#>q#g#o1`~#>tT}!O)z!Q![1`#T#i1`#i#j!<v#j#o1`Q#?WT}!O)z!Q![1`#T#g1`#g#h#?g#h#o1`Q#?jT}!O)z!Q![1`#T#X1`#X#Y#?y#Y#o1`Q#?|T}!O)z!Q![1`#T#f1`#f#g#@]#g#o1`Q#@`S}!O)z!Q![1`!h!iIy#T#o1`",
  tokenizers: [0, 1],
  topRules: {"QueryRequest":[0,2],"ConstraintListRequest":[1,23]},
  tokenPrec: 255
});

function evitaQLLanguage(config) {
    var _a;
    let top;
    if (config.mode instanceof EvitaQLQueryMode) {
        top = 'QueryRequest';
    }
    else if (config.mode instanceof EvitaQLConstraintListMode) {
        top = 'ConstraintListRequest';
    }
    else {
        throw new Error(`Unsupported mode '${(_a = config.mode) === null || _a === void 0 ? void 0 : _a.toString()}'`);
    }
    return language.LRLanguage.define({
        parser: parser.configure({
            top,
            props: [
                language.indentNodeProp.add({
                    "QueryBody ConstraintBody": language.delimitedIndent({ closing: ')', align: true }),
                    Range: language.delimitedIndent({ closing: ']', align: true })
                }),
                language.foldNodeProp.add({
                    'QueryBody ConstraintBody': language.foldInside
                }),
                highlight.styleTags({
                    String: highlight.tags.string,
                    Int: highlight.tags.integer,
                    Float: highlight.tags.float,
                    Boolean: highlight.tags.bool,
                    Date: highlight.tags.literal,
                    Time: highlight.tags.literal,
                    DateTime: highlight.tags.literal,
                    OffsetDateTime: highlight.tags.literal,
                    Uuid: highlight.tags.literal,
                    Enum: highlight.tags.constant(highlight.tags.variableName),
                    Query: highlight.tags.function(highlight.tags.variableName),
                    RootConstraint: highlight.tags.function(highlight.tags.variableName),
                    Constraint: highlight.tags.function(highlight.tags.variableName),
                    Comment: highlight.tags.lineComment,
                    ',': highlight.tags.separator,
                    '( )': highlight.tags.paren,
                    '[ ]': highlight.tags.squareBracket
                })
            ]
        }),
        languageData: {
            commentTokens: { line: '//' }
        }
    });
}

function evitaQL(config = { mode: new EvitaQLQueryMode() }) {
    const lang = evitaQLLanguage(config);
    return new language.LanguageSupport(lang, [evitaQLCompletion(lang, config), evitaQLLinter]);
}

exports.EvitaQLConstraintListMode = EvitaQLConstraintListMode;
exports.EvitaQLQueryMode = EvitaQLQueryMode;
exports.evitaQL = evitaQL;
exports.evitaQLCompletion = evitaQLCompletion;
exports.evitaQLLanguage = evitaQLLanguage;
exports.evitaQLLinter = evitaQLLinter;
